# [tools.ai-parade] pyproject.toml Reference

### ::: ai_parade._toolkit.metadata.models.pyproject.ModelMetadataPyproject

## ::: ai_parade._toolkit.metadata.models.pyproject.InstallOptionsPyproject

	options:
		show_root_heading: true
		show_root_full_path: false

## ::: ai_parade._toolkit.metadata.models.pyproject.PyTorchOptionsPyproject

	options:
		show_root_heading: true
		show_root_full_path: false
